You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@logging.apache.org by gg...@apache.org on 2017/06/24 02:19:09 UTC

logging-log4j2 git commit: Fix typo in varName.

Repository: logging-log4j2
Updated Branches:
  refs/heads/master 9fd6c395f -> 898a2d9b5


Fix typo in varName.

Project: http://git-wip-us.apache.org/repos/asf/logging-log4j2/repo
Commit: http://git-wip-us.apache.org/repos/asf/logging-log4j2/commit/898a2d9b
Tree: http://git-wip-us.apache.org/repos/asf/logging-log4j2/tree/898a2d9b
Diff: http://git-wip-us.apache.org/repos/asf/logging-log4j2/diff/898a2d9b

Branch: refs/heads/master
Commit: 898a2d9b5fbf83d57789a193214a410171658b19
Parents: 9fd6c39
Author: Gary Gregory <gg...@apache.org>
Authored: Fri Jun 23 19:19:06 2017 -0700
Committer: Gary Gregory <gg...@apache.org>
Committed: Fri Jun 23 19:19:06 2017 -0700

----------------------------------------------------------------------
 .../org/apache/logging/log4j/core/appender/mom/JmsManager.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/logging-log4j2/blob/898a2d9b/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/JmsManager.java
----------------------------------------------------------------------
diff --git a/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/JmsManager.java b/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/JmsManager.java
index bedba18..d51dd7a 100644
--- a/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/JmsManager.java
+++ b/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/mom/JmsManager.java
@@ -76,15 +76,15 @@ public class JmsManager extends AbstractManager {
      * @param jndiManager           The JndiManager to look up JMS information through.
      * @param connectionFactoryName The binding name for the {@link javax.jms.ConnectionFactory}.
      * @param destinationName       The binding name for the {@link javax.jms.Destination}.
      * @param username              The username to connect with or {@code null} for no authentication.
      * @param password              The password to use with the given username or {@code null} for no authentication.
      * @return The JmsManager as configured.
      */
     public static JmsManager getJmsManager(final String name, final JndiManager jndiManager,
                                            final String connectionFactoryName, final String destinationName,
-                                           final String username, final String password) {
+                                           final String userName, final String password) {
         final JmsConfiguration configuration = new JmsConfiguration(jndiManager, connectionFactoryName, destinationName,
-            username, password);
+            userName, password);
         return getManager(name, FACTORY, configuration);
     }
@@ -76,15 +76,15 @@ public class JmsManager extends AbstractManager {
      * @param connectionFactoryName The binding name for the {@link javax.jms.ConnectionFactory}.
      * @param destinationName       The binding name for the {@link javax.jms.Destination}.
-     * @param username              The username to connect with or {@code null} for no authentication.
+     * @param userName              The username to connect with or {@code null} for no authentication.
      * @param password              The password to use with the given username or {@code null} for no authentication.
      * @return The JmsManager as configured.